==> vivanta_connect_flutter-0.7.0.tar.gz: lib/views/embedded_graph.dart <==
import 'package:flutter/material.dart';

import 'package:webview_flutter/webview_flutter.dart';

import 'package:vivanta_connect_flutter/services/http.dart';
import 'package:vivanta_connect_flutter/styles/colors.dart';
import 'package:vivanta_connect_flutter/views/loading.dart';

enum GraphType {
  sleep,
  activeTime,
  activity;

  String get name {
    switch (this) {
      case GraphType.sleep:
        return 'sleep_by_week';
      case GraphType.activeTime:
        return 'activities_by_week';
      default:
        return 'steps_by_week';
    }
  }
}

class EmbeddedGraph extends StatefulWidget {
  const EmbeddedGraph({
    Key? key,
    required this.apiKey,
    required this.customerId,
    required this.externalUserId,
    required this.graphType,
    this.brandId,
  }) : super(key: key);

  final GraphType graphType;
  final String apiKey;
  final String customerId;
  final String externalUserId;
  final int? brandId;

  @override
  State<EmbeddedGraph> createState() => _EmbeddedGraphState();
}

class _EmbeddedGraphState extends State<EmbeddedGraph> {
  late WebViewController _controller;
  bool _loading = false;

  @override
  void initState() {
    generateGraph();
    _controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..clearLocalStorage()
      ..setBackgroundColor(VivantaColors.background)
      ..setNavigationDelegate(NavigationDelegate(
        onProgress: (progress) {
          setState(() {
            _loading = progress < 100;
          });
        },
        onPageStarted: (url) {},
        onPageFinished: (url) {
          setState(() {
            _loading = false;
          });
        },
        onWebResourceError: (WebResourceError error) {},
        onNavigationRequest: (NavigationRequest request) {
          return NavigationDecision.navigate;
        },
      ));
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _loading
        ? const Loading()
        : Scaffold(
            backgroundColor: VivantaColors.background,
            appBar: AppBar(
              backgroundColor: VivantaColors.background,
              elevation: 0,
              leading: GestureDetector(
                onTap: () {
                  Navigator.of(context).maybePop();
                },
                child: const Icon(
                  Icons.arrow_back_ios,
                  color: VivantaColors.text,
                  size: 24,
                ),
              ),
            ),
            body: Column(
              children: [
                Expanded(
                  child: WebViewWidget(
                    controller: _controller,
                  ),
                ),
              ],
            ),
          );
  }

  Future<void> generateGraph() async {
    setState(() {
      _loading = true;
    });
    final http = Http();
    final graphUrl = await http.getEmbeddedGraphResource(
      widget.apiKey,
      widget.customerId,
      widget.externalUserId,
      widget.graphType.name,
      brandId: widget.brandId,
    );

    if (graphUrl != null) {
      _controller.loadRequest(Uri.parse(graphUrl));
    }
  }
}

==> vivanta_connect_flutter-0.7.1.tar.gz: lib/views/embedded_graph.dart <==
import 'package:flutter/material.dart';

import 'package:webview_flutter/webview_flutter.dart';

import 'package:vivanta_connect_flutter/services/http.dart';
import 'package:vivanta_connect_flutter/styles/colors.dart';
import 'package:vivanta_connect_flutter/views/loading.dart';

enum GraphType {
  sleep,
  activeTime,
  activity;

  String get name {
    switch (this) {
      case GraphType.sleep:
        return 'sleep_by_week';
      case GraphType.activeTime:
        return 'activities_by_week';
      default:
        return 'steps_by_week';
    }
  }
}

class EmbeddedGraph extends StatefulWidget {
  const EmbeddedGraph({
    Key? key,
    required this.apiKey,
    required this.customerId,
    required this.externalUserId,
    required this.graphType,
    this.brandId,
  }) : super(key: key);

  final GraphType graphType;
  final String apiKey;
  final String customerId;
  final String externalUserId;
  final int? brandId;

  @override
  State<EmbeddedGraph> createState() => _EmbeddedGraphState();
}

class _EmbeddedGraphState extends State<EmbeddedGraph> {
  late WebViewController _controller;
  bool _loading = false;

  @override
  void initState() {
    generateGraph();
    _controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..clearLocalStorage()
      ..setBackgroundColor(VivantaColors.background)
      ..setNavigationDelegate(NavigationDelegate(
        onProgress: (progress) {
          setState(() {
            _loading = progress < 100;
          });
        },
        onPageStarted: (url) {},
        onPageFinished: (url) {
          setState(() {
            _loading = false;
          });
        },
        onWebResourceError: (WebResourceError error) {},
        onNavigationRequest: (NavigationRequest request) {
          return NavigationDecision.navigate;
        },
      ));
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _loading
        ? const Loading()
        : Scaffold(
            backgroundColor: VivantaColors.background,
            appBar: AppBar(
              backgroundColor: VivantaColors.background,
              elevation: 0,
              title: const Center(
                child: Image(
                  image: AssetImage(
                    "images/vivanta-logo.png",
                    package: 'vivanta_connect_flutter',
                  ),
                  height: 20,
                  fit: BoxFit.cover,
                ),
              ),
              actions: [
                Padding(
                  padding: const EdgeInsets.only(right: 16),
                  child: GestureDetector(
                    onTap: () {
                      Navigator.of(context).maybePop();
                    },
                    child: const Icon(
                      Icons.close,
                      color: VivantaColors.text,
                      size: 24,
                    ),
                  ),
                ),
              ],
            ),
            body: Column(
              children: [
                Expanded(
                  child: WebViewWidget(
                    controller: _controller,
                  ),
                ),
              ],
            ),
          );
  }

  Future<void> generateGraph() async {
    setState(() {
      _loading = true;
    });
    final http = Http();
    final graphUrl = await http.getEmbeddedGraphResource(
      widget.apiKey,
      widget.customerId,
      widget.externalUserId,
      widget.graphType.name,
      brandId: widget.brandId,
    );

    if (graphUrl != null) {
      _controller.loadRequest(Uri.parse(graphUrl));
    }
  }
}
